/**************************************************
*  libsir.h - Header file for libsir.c
*  SIR image file format utility library
*  written by: DGL 16 Apr 2003
*  revised: DGL  6 Aug 2017
*  (C) 2003,2017 Brigham Young University
***************************************************/

#ifndef LIBSIR_H
#define LIBSIR_H

#define SHORT short
#define FLOAT float

#include "sir_cpp.h"

// key function prototypes

// since the actual SIR file read/writing and geometric manipulation
// is done with C code, classes are not used

extern void print_sir_header(sirheader *h);
extern int read_sir_header(FILE *imf, sirheader *h);
extern int read_sir_data(FILE *imf, float *data, sirheader *h);
extern float *LoadSIR(char *filename, sirheader *h);
extern void pixtolatlon(sirheader *h, float px, float py, float *lon, float *lat);
extern void ipixtolatlon(sirheader *h, int px, int py, float *lon, float *lat);
extern int latlon2pix(sirheader *h, float lon, float lat, float *px, float *py);
extern void ilatlon2pix(sirheader *h, float lon, float lat, int *px, int *py);
extern int sir_datablock(FILE *imf, float *stval, sirheader *sh,
			 int x1, int y1, int x2, int y2);
extern int PutSIR(char *filename, sirheader *h, float *image);
extern int SIRlex(int x, int y, sirheader *h);
extern int iSIRlex(int *x, int *y, int i, sirheader *h);

/* double precision SIR routine function prototypes */
extern void dpixtolatlon(double x, double y, double *alon, double *alat, 
			 int iopt, float xdeg, float ydeg,
			 float ascale, float bscale, float a0, float b0);
extern void dlatlon2pix(double alon, double alat, double *x, double *y, 
			int iopt, float xdeg, float ydeg,
			float ascale, float bscale, float a0, float b0);
extern void df2ipix(double x, double y, int *ix, int *iy, int nsx, int nsy);
extern void dsir_pix2latlon(double x, double y, double *alon, double *alat, sir_head *head);
extern int dsir_latlon2pix(double alon, double alat, double *x, double *y, sir_head *head);
extern int dsir_pix(double x, double y, int *ix, int *iy, sir_head *head);

#endif
